=========================================
Django Object Permissions' documentation!
=========================================

Django Object Permissions is a way to add a custom set of user-object or group-object permissions. It does not replace Django's built-in permissions. Instead it augments them by adding additional ways to manage access to specific objects.

You can add object permissions to existing apps (e.g. Flat Pages) without modifying the app's code, or build it into your own application.

It uses an efficient method of storing permissions; it requires only one row per user-object combination, regardless of the number of permissions granted.

Our initial goals were pretty simple (in thought, not necessarily in deed):

* Have an easy way to set read/write/owner permissions on an object or row
* Easy to discover if a given user has a level of permission
* Customizable permissions by model
* Admin viewing/editing integration

This is a proof-of-concept right now and we are looking for feedback for tweaks in implementation or new ideas to implement.

Contents:

.. toctree::
   :maxdepth: 2
   :glob:
   
   getting_started
   signals
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

